@@ -83,6 +83,11 @@ int TCPConnection::getPacketCount()
 	return packet_count;
 }
 
+long TCPConnection::getPayloadByteCount()
+{
+	return payload_byte_count;
+}
+
 int TCPConnection::getState()
 {
 	return state;
@@ -110,6 +115,8 @@ TCPConnection::TCPConnection( IPv4TCPCapture &p )
 	payload_bytes_last_second = 0;
 	all_bytes_last_second = 0;
 
+	payload_byte_count = p.ipv4().payloadLen() - p.ipv4().tcp().headerLen();
+
 	last_pkt_ts = time(NULL);
 	activity_toggle=false;
 	
@@ -253,6 +260,8 @@ void TCPConnection::updateCountersForPacket( IPv4TCPCapture &p )
 			payload_bytes_this_second += p.ipv4().payloadLen() - p.ipv4().tcp().headerLen();
 			all_bytes_this_second += p.ipv4().totalLen();
 		}
+
+        payload_byte_count += p.ipv4().payloadLen() - p.ipv4().tcp().headerLen();
 	}
 }
 
