@@ -43,7 +43,7 @@ TextUI::TextUI( TCContainer *c )
 	state=USTATE_IDLE;
 
 	paused=false;
-	sorted=true;
+	sort_type=SORT_UN;
 
 	pthread_mutex_init( &state_mutex, NULL );
 }
@@ -158,7 +158,20 @@ void TextUI::displayer_run()
 				app->shutdown();
 			}
 			else if( c=='s' )
-				sorted=!sorted;
+			{
+				switch( sort_type )
+				{
+					case SORT_UN:
+						sort_type=SORT_RATE;
+						break;
+					case SORT_RATE:
+						sort_type=SORT_BYTES;
+						break;
+					case SORT_BYTES:
+						sort_type=SORT_UN;
+						break;
+				}
+			}
 			else if( c=='p' )
 			{
 				if( paused==true ) 
@@ -250,8 +263,8 @@ void TextUI::drawui()
 
 	i->rewind();
 	
-	if( sorted ) 
-		i->sort();
+	if( sort_type != SORT_UN ) 
+		i->sort( sort_type );
 
 	int ic_i=0; // for scrolling
 	while( TCPConnection *ic=i->getNext() )
@@ -331,7 +344,7 @@ void TextUI::drawui()
 	else 
 		printw("Connections 0-0 of 0");
 		
-	move(bottom-1,56);
+	move(bottom-1,46);
 	if( paused==true )
 	{
 		attron(A_UNDERLINE);
@@ -349,21 +362,28 @@ void TextUI::drawui()
 	}
 
 
-	move(bottom-1,66);
-	if( sorted==false ) 
+	move(bottom-1,56);
+    switch( sort_type )
 	{
+	case SORT_UN:
 		printw("Un");
 		attron(A_UNDERLINE);
 		printw("s");
 		attroff(A_UNDERLINE);
 		printw("orted");
-	}
-	else
-	{
+		break;
+	case SORT_RATE:
 		attron(A_UNDERLINE);
 		printw("S");
 		attroff(A_UNDERLINE);
-		printw("orted");
+		printw("orted by rate");
+		break;
+	case SORT_BYTES:
+		attron(A_UNDERLINE);
+		printw("S");
+		attroff(A_UNDERLINE);
+		printw("orted by bytes");
+		break;
 	}
 
 	attroff(A_REVERSE);
